@@ -8,10 +8,10 @@ from fideslog.sdk.python.client import AnalyticsClient
 
 import fidesctl
 from fidesctl.cli.utils import check_and_update_analytics_config, check_server
-from fidesctl.core.config import get_config
+from fidesctl.ctl.core.config import get_config
 
 from .commands.annotate import annotate
-from .commands.core import apply, evaluate, parse, sync
+from .commands.core import apply, evaluate, parse, pull, push
 from .commands.crud import delete, get, ls
 from .commands.db import database
 from .commands.export import export
@@ -21,20 +21,12 @@ from .commands.util import init, status, webserver
 from .commands.view import view
 
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
-LOCAL_COMMANDS = [evaluate, init, parse, view, webserver]
-API_COMMANDS = [
-    annotate,
-    apply,
-    database,
-    delete,
-    export,
-    generate,
-    get,
-    ls,
-    scan,
-    status,
-    sync,
-]
+LOCAL_COMMANDS = [evaluate, generate, init, scan, parse, view, webserver]
+LOCAL_COMMAND_DICT = {
+    command.name or str(command): command for command in LOCAL_COMMANDS
+}
+API_COMMANDS = [annotate, apply, database, delete, export, get, ls, status, pull, push]
+API_COMMAND_DICT = {command.name or str(command): command for command in API_COMMANDS}
 ALL_COMMANDS = API_COMMANDS + LOCAL_COMMANDS
 SERVER_CHECK_COMMAND_NAMES = [
     command.name for command in API_COMMANDS if command.name not in ["status"]
@@ -70,14 +62,12 @@ def cli(ctx: click.Context, config_path: str, local: bool) -> None:
     ctx.ensure_object(dict)
     config = get_config(config_path)
 
-    for command in LOCAL_COMMANDS:
-        cli.add_command(command)
+    # Dyanmically add commands to the CLI
+    cli.commands = LOCAL_COMMAND_DICT
 
-    # If local_mode is enabled, don't add unsupported commands
     if not (local or config.cli.local_mode):
         config.cli.local_mode = False
-        for command in API_COMMANDS:
-            cli.add_command(command)
+        cli.commands = {**cli.commands, **API_COMMAND_DICT}
     else:
         config.cli.local_mode = True
 
@@ -107,9 +97,6 @@ def cli(ctx: click.Context, config_path: str, local: bool) -> None:
             )
 
 
-# This is a special section used for auto-generating the CLI docs
-# This has to be done due to the dynamic way in which commands are added for the real CLI group
-cli_docs = cli
-
+# Add all commands here before dynamically checking them in the CLI
 for cli_command in ALL_COMMANDS:
-    cli_docs.add_command(cli_command)
+    cli.add_command(cli_command)
